/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */

#include "NoWeapon.h"
#include "System/mmgr.h"

CR_BIND_DERIVED(CNoWeapon, CWeapon, (NULL));

CNoWeapon::CNoWeapon(CUnit *owner) : CWeapon(owner)
{
	weaponDef=0;
}


CNoWeapon::~CNoWeapon(void)
{
}

void CNoWeapon::Update(void)
{
}

bool CNoWeapon::TryTarget(const float3& pos,bool userTarget,CUnit* unit)
{
	return false;
}

void CNoWeapon::Init(void)
{
}

void CNoWeapon::FireImpl()
{
}

void CNoWeapon::SlowUpdate()
{
}

